==> apache-qpid-jms-1.9.0-src.tar.gz: apache-qpid-jms-1.9.0-src/qpid-jms-client/src/test/java/org/apache/qpid/jms/transports/netty/NettyWssTransportTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms.transports.netty;

import java.net.URI;

import org.apache.qpid.jms.test.proxy.TestProxy;
import org.apache.qpid.jms.transports.TransportListener;
import org.apache.qpid.jms.transports.TransportOptions;
import org.junit.Test;

/**
 * Test the NettyWsTransport with channel level security enabled.
 */
public class NettyWssTransportTest extends NettySslTransportTest {

    @Override
    protected NettyEchoServer createEchoServer(TransportOptions options, boolean needClientAuth) {
        return new NettyEchoServer(options, true, needClientAuth, true);
    }

    @Override
    protected NettyTcpTransport createTransport(URI serverLocation, TransportListener listener, TransportOptions options) {
        if (listener == null) {
            return new NettyWsTransport(serverLocation, options, true);
        } else {
            return new NettyWsTransport(listener, serverLocation, options, true);
        }
    }

    @Test(timeout = 60 * 1000)
    public void testConnectViaHttpProxyToServerVerifyHost() throws Exception {
        doConnectToServerVerifyHostTestImpl(true, TestProxy.ProxyType.HTTP);
    }

    @Test(timeout = 60 * 1000)
    public void testConnectViaHttpProxyToServerNoVerifyHost() throws Exception {
        doConnectToServerVerifyHostTestImpl(false, TestProxy.ProxyType.HTTP);
    }
}

==> apache-qpid-jms-2.5.0-src.tar.gz: apache-qpid-jms-2.5.0-src/qpid-jms-client/src/test/java/org/apache/qpid/jms/transports/netty/NettyWssTransportTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms.transports.netty;

import java.net.URI;

import org.apache.qpid.jms.test.proxy.TestProxy;
import org.apache.qpid.jms.transports.TransportListener;
import org.apache.qpid.jms.transports.TransportOptions;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.Timeout;

/**
 * Test the NettyWsTransport with channel level security enabled.
 */
public class NettyWssTransportTest extends NettySslTransportTest {

    @Override
    protected NettyEchoServer createEchoServer(TransportOptions options, boolean needClientAuth) {
        return new NettyEchoServer(options, true, needClientAuth, true);
    }

    @Override
    protected NettyTcpTransport createTransport(URI serverLocation, TransportListener listener, TransportOptions options) {
        if (listener == null) {
            return new NettyWsTransport(serverLocation, options, true);
        } else {
            return new NettyWsTransport(listener, serverLocation, options, true);
        }
    }

    @Test
    @Timeout(60)
    public void testConnectViaHttpProxyToServerVerifyHost() throws Exception {
        doConnectToServerVerifyHostTestImpl(true, TestProxy.ProxyType.HTTP);
    }

    @Test
    @Timeout(60)
    public void testConnectViaHttpProxyToServerNoVerifyHost() throws Exception {
        doConnectToServerVerifyHostTestImpl(false, TestProxy.ProxyType.HTTP);
    }
}
